@@ -242,6 +242,9 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("column-mode", "c", false, "column mode")
 	_ = viper.BindPFlag("general.ColumnMode", rootCmd.PersistentFlags().Lookup("column-mode"))
 
+	rootCmd.PersistentFlags().BoolP("column-rainbow", "", false, "column rainbow")
+	_ = viper.BindPFlag("general.ColumnRainbow", rootCmd.PersistentFlags().Lookup("column-rainbow"))
+
 	rootCmd.PersistentFlags().BoolP("line-number", "n", false, "line number mode")
 	_ = viper.BindPFlag("general.LineNumMode", rootCmd.PersistentFlags().Lookup("line-number"))
 
@@ -276,7 +279,7 @@ func init() {
 	_ = viper.BindPFlag("general.WatchInterval", rootCmd.PersistentFlags().Lookup("watch"))
 
 	rootCmd.PersistentFlags().StringSliceP("multi-color", "M", nil, "multi-color")
-	_ = viper.BindPFlag("MultiColorWords", rootCmd.PersistentFlags().Lookup("multi-color"))
+	_ = viper.BindPFlag("general.MultiColorWords", rootCmd.PersistentFlags().Lookup("multi-color"))
 
 	rootCmd.PersistentFlags().StringP("jump-target", "j", "", "jump-target")
 	_ = viper.BindPFlag("general.JumpTargetString", rootCmd.PersistentFlags().Lookup("jump-target"))
@@ -306,6 +309,9 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("incsearch", "", true, "incremental search")
 	_ = viper.BindPFlag("Incsearch", rootCmd.PersistentFlags().Lookup("incsearch"))
 
+	rootCmd.PersistentFlags().StringP("view-mode", "", "", "view mode")
+	_ = viper.BindPFlag("ViewMode", rootCmd.PersistentFlags().Lookup("view-mode"))
+
 	rootCmd.PersistentFlags().BoolP("debug", "", false, "debug mode")
 	_ = viper.BindPFlag("Debug", rootCmd.PersistentFlags().Lookup("debug"))
 }
