@@ -41,6 +41,18 @@ func (root *Root) toggleLineNumMode() {
 	root.setMessagef("Set LineNumMode %t", root.Doc.LineNumMode)
 }
 
+// togglePlain toggles plain mode.
+func (root *Root) togglePlain() {
+	root.Doc.PlainMode = !root.Doc.PlainMode
+	root.setMessagef("Set PrainMode %t", root.Doc.PlainMode)
+}
+
+// togglePlain toggles column rainbow mode.
+func (root *Root) toggleRainbow() {
+	root.Doc.ColumnRainbow = !root.Doc.ColumnRainbow
+	root.setMessagef("Set Column Rainbow Mode %t", root.Doc.ColumnRainbow)
+}
+
 // toggleFollowMode toggles follow mode.
 func (root *Root) toggleFollowMode() {
 	root.Doc.FollowMode = !root.Doc.FollowMode
@@ -56,11 +68,6 @@ func (root *Root) toggleFollowSection() {
 	root.Doc.FollowSection = !root.Doc.FollowSection
 }
 
-// togglePlain toggles follow section mode.
-func (root *Root) togglePlain() {
-	root.Doc.PlainMode = !root.Doc.PlainMode
-}
-
 // closeFile close the file.
 func (root *Root) closeFile() {
 	if root.screenMode != Docs {
@@ -140,7 +147,7 @@ func (root *Root) goLine(input string) {
 	if len(input) == 0 {
 		return
 	}
-	num := targetToN(root.Doc.endNum, input)
+	num := position(root.Doc.endNum, input)
 	str := strconv.FormatFloat(num, 'f', 1, 64)
 	if strings.HasSuffix(str, ".0") {
 		// Line number only.
@@ -315,11 +322,11 @@ func (root *Root) toggleMouse() {
 
 // setViewMode switches to the preset display mode.
 // Set header lines and columMode together.
-func (root *Root) setViewMode(input string) {
-	c, ok := root.Config.Mode[input]
+func (root *Root) setViewMode(modeName string) {
+	c, ok := root.Config.Mode[modeName]
 	if !ok {
-		if input != "general" {
-			root.setMessagef("%s mode not found", input)
+		if modeName != "general" {
+			root.setMessagef("%s mode not found", modeName)
 			return
 		}
 		c = root.General
@@ -327,9 +334,10 @@ func (root *Root) setViewMode(input string) {
 
 	root.Doc.general = overwriteGeneral(root.Doc.general, c)
 	root.Doc.setSectionDelimiter(root.Doc.SectionDelimiter)
+	root.Doc.setMultiColorWords(root.Doc.MultiColorWords)
 	root.Doc.ClearCache()
 	root.ViewSync()
-	root.setMessagef("Set mode %s", input)
+	root.setMessagef("Set mode %s", modeName)
 }
 
 // setDelimiter sets the delimiter string.
@@ -442,7 +450,7 @@ func (root *Root) setMultiColor(input string) {
 
 // setJumpTarget sets the position of the search result.
 func (root *Root) setJumpTarget(input string) {
-	num := int(math.Round(strToPosition(root.vHight, input)))
+	num := jumpPosition(root.vHight, input)
 	if num < 0 || num > root.vHight-1 {
 		root.setMessagef("Set JumpTarget %d: %s", num, ErrOutOfRange.Error())
 		return
@@ -457,24 +465,23 @@ func (root *Root) setJumpTarget(input string) {
 
 // resize is a wrapper function that calls viewSync.
 func (root *Root) resize() {
-	root.Doc.JumpTarget = int(math.Round(strToPosition(root.vHight, root.Doc.JumpTargetString)))
 	root.ViewSync()
 }
 
-// strToPositon determines the position of the jump.
-func strToPosition(hight int, str string) float64 {
-	num := targetToN(hight, str)
+// jumpPosition determines the position of the jump.
+func jumpPosition(hight int, str string) int {
+	num := int(math.Round(position(hight, str)))
 	if num < 0 {
-		return (float64(hight) - 1) + num
+		return (hight - 1) + num
 	}
 	return num
 }
 
-// targetToN returns
+// position returns
 // the number of lines from the top for positive numbers (1),
 // dot.number for percentages (.5) = 50%,
 // and % after the number for percentages (50%).
-func targetToN(hight int, str string) float64 {
+func position(hight int, str string) float64 {
 	str = strings.TrimSpace(str)
 	if len(str) == 0 {
 		return 0
@@ -517,6 +524,7 @@ func (root *Root) ViewSync() {
 	root.prepareStartX()
 	root.prepareView()
 	root.Screen.Sync()
+	root.Doc.JumpTarget = jumpPosition(root.vHight, root.Doc.JumpTargetString)
 }
 
 // TailSync move to tail and sync.
