@@ -315,6 +315,7 @@ func (m *Document) BackSearchLine(ctx context.Context, searcher Searcher, lN int
 	return 0, ErrNotFound
 }
 
+// watchMode sets the document to watch mode.
 func (m *Document) watchMode() {
 	m.WatchMode = true
 	if m.SectionDelimiter == "" {
@@ -324,25 +325,27 @@ func (m *Document) watchMode() {
 	m.FollowSection = true
 }
 
+// unwatchMode unwatch mode for the document.
 func (m *Document) unWatchMode() {
 	m.WatchMode = false
 	m.FollowSection = false
 }
 
+// setSectionDelimiter sets the document section delimiter.
 func (m *Document) setSectionDelimiter(delm string) {
 	m.SectionDelimiter = delm
 	m.SectionDelimiterReg = regexpCompile(delm, true)
 }
 
-// setMultiColor set multiple strings to highlight with multiple colors.
+// setMultiColorWords set multiple strings to highlight with multiple colors.
 func (m *Document) setMultiColorWords(words []string) {
-	m.multiColorRegexps = nil
-	for _, w := range words {
+	regexps := make([]*regexp.Regexp, len(words))
+	for n, w := range words {
 		s, err := strconv.Unquote(w)
 		if err != nil {
 			s = w
 		}
-		reg := regexpCompile(s, true)
-		m.multiColorRegexps = append(m.multiColorRegexps, reg)
+		regexps[n] = regexpCompile(s, true)
 	}
+	m.multiColorRegexps = regexps
 }
