@@ -64,9 +64,9 @@ func (root *Root) drawHeader() int {
 
 		lc := m.getContents(lY, m.TabWidth)
 		lineStr, posCV := m.getContentsStr(lY, lc)
-		root.lnumber[hy] = lineNumber{
-			line: lY,
-			wrap: wrapNum,
+		root.lines[hy] = line{
+			number: lY,
+			wrap:   wrapNum,
 		}
 
 		root.columnHighlight(lc, lineStr, posCV)
@@ -109,15 +109,15 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 			lastLN = lY
 		}
 
-		root.lnumber[y] = lineNumber{
-			line: lY,
-			wrap: wrapNum,
+		root.lines[y] = line{
+			number: lY,
+			wrap:   wrapNum,
 		}
 
-		root.columnHighlight(lc, lineStr, posCV)
 		if root.Doc.PlainMode {
-			root.plainMode(lc)
+			root.plainStyle(lc)
 		}
+		root.columnHighlight(lc, lineStr, posCV)
 		root.multiColorHighlight(lc, lineStr, posCV)
 		root.searchHighlight(lY, lc, lineStr, posCV)
 		root.drawLineNumber(lY, y)
@@ -221,18 +221,21 @@ func (root *Root) searchHighlight(lY int, lc contents, lineStr string, posCV map
 	}
 }
 
-func (root *Root) plainMode(lc contents) {
+// plainStyle defaults to the original style.
+func (root *Root) plainStyle(lc contents) {
 	for x := 0; x < len(lc); x++ {
 		lc[x].style = tcell.StyleDefault
 	}
 }
 
+// multiColorHighlight applies styles to multiple words (regular expressions) individually.
+// The style of the first specified word takes precedence.
 func (root *Root) multiColorHighlight(lc contents, str string, posCV map[int]int) {
 	numC := len(root.StyleMultiColorHighlight)
-	for n, w := range root.Doc.multiColorRegexps {
-		poss := searchPositionReg(str, w)
+	for i := len(root.Doc.multiColorRegexps) - 1; i >= 0; i-- {
+		poss := searchPositionReg(str, root.Doc.multiColorRegexps[i])
 		for _, r := range poss {
-			RangeStyle(lc, posCV[r[0]], posCV[r[1]], root.StyleMultiColorHighlight[n%numC])
+			RangeStyle(lc, posCV[r[0]], posCV[r[1]], root.StyleMultiColorHighlight[i%numC])
 		}
 	}
 }
@@ -267,8 +270,31 @@ func (root *Root) columnHighlight(lc contents, str string, posCV map[int]int) {
 	if !root.Doc.ColumnMode {
 		return
 	}
-	start, end := rangePosition(str, root.Doc.ColumnDelimiter, root.Doc.columnNum)
-	RangeStyle(lc, posCV[start], posCV[end], root.StyleColumnHighlight)
+
+	delm := root.Doc.ColumnDelimiter
+	numC := len(root.StyleColumnRainbow)
+	c := 0
+	offset := 0
+	for i := strings.Index(str, delm); i >= 0; i = strings.Index(str[offset:], delm) {
+		if root.Doc.ColumnRainbow {
+			RangeStyle(lc, posCV[offset], posCV[offset+i], root.StyleColumnRainbow[c%numC])
+		}
+		if c == root.Doc.columnNum {
+			RangeStyle(lc, posCV[offset], posCV[offset+i], root.StyleColumnHighlight)
+		}
+		offset = offset + i + len(delm)
+		if offset != 1 {
+			c++
+		}
+	}
+	if offset < len(str) {
+		if root.Doc.ColumnRainbow {
+			RangeStyle(lc, posCV[offset], posCV[len(str)], root.StyleColumnRainbow[c%numC])
+		}
+		if c == root.Doc.columnNum && offset != 0 {
+			RangeStyle(lc, posCV[offset], posCV[len(str)], root.StyleColumnHighlight)
+		}
+	}
 }
 
 // RangeStyle applies the style to the specified range.
@@ -321,7 +347,7 @@ func (root *Root) drawStatus() {
 }
 
 func (root *Root) leftStatus() (contents, int) {
-	if root.input.mode == Normal {
+	if root.input.Event.Mode() == Normal {
 		return root.normalLeftStatus()
 	}
 	return root.inputLeftStatus()
@@ -365,8 +391,9 @@ func (root *Root) normalLeftStatus() (contents, int) {
 
 func (root *Root) inputLeftStatus() (contents, int) {
 	input := root.input
+	mode := input.Event.Mode()
 	searchMode := ""
-	if input.mode == Search || input.mode == Backsearch {
+	if mode == Search || mode == Backsearch {
 		if root.Config.RegexpSearch {
 			searchMode += "(R)"
 		}
@@ -377,7 +404,7 @@ func (root *Root) inputLeftStatus() (contents, int) {
 			searchMode += "(Aa)"
 		}
 	}
-	p := searchMode + input.EventInput.Prompt()
+	p := searchMode + input.Event.Prompt()
 	leftStatus := p + input.value
 	leftContents := StrToContents(leftStatus, -1)
 	return leftContents, len(p) + input.cursorX
