@@ -8,6 +8,8 @@ import (
 	"github.com/gdamore/tcell/v2"
 )
 
+// The name of the action to assign the key to.
+// The string is displayed in help.
 const (
 	actionExit           = "exit"
 	actionWriteBA        = "set_write_exit"
@@ -19,6 +21,7 @@ const (
 	actionFollowAll      = "follow_all"
 	actionFollowSection  = "follow_section"
 	actionPlain          = "plain_mode"
+	actionRainbow        = "rainbow_mode"
 	actionCloseFile      = "close_file"
 	actionReload         = "reload"
 	actionWatch          = "watch"
@@ -73,7 +76,8 @@ const (
 	inputRegexpSearch  = "input_regexp_search"
 )
 
-func (root *Root) setHandler() map[string]func() {
+// handlerMap returns a map of the action's handlers.
+func (root *Root) handlerMap() map[string]func() {
 	return map[string]func(){
 		actionExit:           root.Quit,
 		actionWriteBA:        root.setWriteBAMode,
@@ -85,6 +89,7 @@ func (root *Root) setHandler() map[string]func() {
 		actionFollowAll:      root.toggleFollowAll,
 		actionFollowSection:  root.toggleFollowSection,
 		actionPlain:          root.togglePlain,
+		actionRainbow:        root.toggleRainbow,
 		actionReload:         root.Reload,
 		actionWatch:          root.toggleWatch,
 		actionWatchInterval:  root.setWatchIntervalMode,
@@ -125,8 +130,8 @@ func (root *Root) setHandler() map[string]func() {
 		actionSkipLines:      root.setSkipLinesMode,
 		actionTabWidth:       root.setTabWidthMode,
 		actionGoLine:         root.setGoLineMode,
-		actionNextSearch:     root.eventNextSearch,
-		actionNextBackSearch: root.eventNextBackSearch,
+		actionNextSearch:     root.setNextSearch,
+		actionNextBackSearch: root.setNextBackSearch,
 		actionNextDoc:        root.nextDoc,
 		actionPreviousDoc:    root.previousDoc,
 		actionCloseDoc:       root.closeDocument,
@@ -143,6 +148,7 @@ func (root *Root) setHandler() map[string]func() {
 // KeyBind is the mapping of action and key.
 type KeyBind map[string][]string
 
+// defaultKeyBinds are the default keybindings.
 func defaultKeyBinds() map[string][]string {
 	return map[string][]string{
 		actionExit:           {"Escape", "q"},
@@ -154,6 +160,7 @@ func defaultKeyBinds() map[string][]string {
 		actionFollowAll:      {"ctrl+a"},
 		actionFollowSection:  {"F2"},
 		actionPlain:          {"ctrl+e"},
+		actionRainbow:        {"ctrl+r"},
 		actionCloseFile:      {"ctrl+F9", "ctrl+alt+s"},
 		actionReload:         {"F5", "ctrl+alt+l"},
 		actionWatch:          {"F4", "ctrl+alt+w"},
@@ -231,7 +238,7 @@ func (root *Root) setKeyBind(keyBind map[string][]string) error {
 	c := root.keyConfig
 	in := root.inputKeyConfig
 
-	actionHandlers := root.setHandler()
+	actionHandlers := root.handlerMap()
 
 	for name, keys := range keyBind {
 		handler := actionHandlers[name]
