@@ -69,9 +69,9 @@ type Root struct {
 	// startX is the start position of x.
 	startX int
 
-	// lnumber is an array that returns
-	// lineNumber (number of logical lines and number of wrapping lines) from y on the screen.
-	lnumber []lineNumber
+	// lines is the line information of the currently displayed screen.
+	// lines (number of logical lines and number of wrapping lines) from y on the screen.
+	lines []line
 
 	// skipDraw skips draw once when true.
 	// skipDraw is set to true when the mouse cursor just moves (no event occurs).
@@ -102,10 +102,10 @@ type Root struct {
 	cancelKeys []string
 }
 
-// LineNumber is Number of logical lines and number of wrapping lines on the screen.
-type lineNumber struct {
-	line int
-	wrap int
+// Line is Number of logical lines and number of wrapping lines on the screen.
+type line struct {
+	number int
+	wrap   int
 }
 
 // general structure contains the general of the display.
@@ -121,6 +121,8 @@ type general struct {
 	AlternateRows bool
 	// ColumnMode is column mode.
 	ColumnMode bool
+	// ColumnRainbow is column rainbow.
+	ColumnRainbow bool
 	// LineNumMode displays line numbers.
 	LineNumMode bool
 	// Wrap is Wrap mode.
@@ -149,6 +151,8 @@ type general struct {
 	JumpTargetString string
 	// JumpTarget is the display position of search results.
 	JumpTarget int
+	// MultiColorWords specifies words to color separated by spaces.
+	MultiColorWords []string
 }
 
 // Config represents the settings of ov.
@@ -175,6 +179,8 @@ type Config struct {
 	StyleSectionLine OVStyle
 	// StyleMultiColorHighlight is the style that applies to the multi color highlight.
 	StyleMultiColorHighlight []OVStyle
+	// StyleColumnRainbow  is the style that applies to the column rainbow color highlight.
+	StyleColumnRainbow []OVStyle
 	// StyleJumpTargetLine is the line that displays the search results.
 	StyleJumpTargetLine OVStyle
 
@@ -193,8 +199,6 @@ type Config struct {
 	// AfterWriteOriginal specifies the number of lines after the current position.
 	// 0 specifies the bottom of the screen.
 	AfterWriteOriginal int
-	// MultiColorWords specifies words to color separated by spaces.
-	MultiColorWords []string
 
 	// QuiteSmall Quit if the output fits on one screen.
 	QuitSmall bool
@@ -212,8 +216,11 @@ type Config struct {
 	// KeyBinding
 	Keybind map[string][]string
 
-	// Old setting.
+	// ViewMode represents the view mode.
+	// ViewMode sets several settings together and can be easily switched.
+	ViewMode string
 
+	// Old setting.
 	// Deprecated: Alternating background color.
 	ColorAlternate string
 	// Deprecated: Header color.
@@ -342,57 +349,6 @@ func NewOviewer(docs ...*Document) (*Root, error) {
 	return root, nil
 }
 
-// NewConfig return the structure of Config with default values.
-func NewConfig() Config {
-	return Config{
-		StyleHeader: OVStyle{
-			Bold: true,
-		},
-		StyleAlternate: OVStyle{
-			Background: "gray",
-		},
-		StyleOverStrike: OVStyle{
-			Bold: true,
-		},
-		StyleOverLine: OVStyle{
-			Underline: true,
-		},
-		StyleLineNumber: OVStyle{
-			Bold: true,
-		},
-		StyleSearchHighlight: OVStyle{
-			Reverse: true,
-		},
-		StyleColumnHighlight: OVStyle{
-			Reverse: true,
-		},
-		StyleMarkLine: OVStyle{
-			Background: "darkgoldenrod",
-		},
-		StyleSectionLine: OVStyle{
-			Background: "slateblue",
-		},
-		StyleMultiColorHighlight: []OVStyle{
-			{Foreground: "red"},
-			{Foreground: "aqua"},
-			{Foreground: "yellow"},
-			{Foreground: "fuchsia"},
-			{Foreground: "lime"},
-			{Foreground: "blue"},
-			{Foreground: "grey"},
-		},
-		StyleJumpTargetLine: OVStyle{
-			Underline: true,
-		},
-		General: general{
-			TabWidth:             8,
-			MarkStyleWidth:       1,
-			SectionStartPosition: 0,
-			JumpTarget:           0,
-		},
-	}
-}
-
 // NewRoot returns the structure of the oviewer.
 // NewRoot is a simplified version that can be used externally.
 func NewRoot(r io.Reader) (*Root, error) {
@@ -560,12 +516,15 @@ func (root *Root) Run() error {
 	root.Config.General.SectionDelimiterReg = regexpCompile(root.Config.General.SectionDelimiter, true)
 
 	root.optimizedMan()
-
+	root.setModeConfig()
+	viewMode, overwrite := root.Config.Mode[root.Config.ViewMode]
 	for n, doc := range root.DocList {
 		doc.general = root.Config.General
-
-		if root.Config.MultiColorWords != nil {
-			doc.setMultiColorWords(root.Config.MultiColorWords)
+		if overwrite {
+			doc.general = overwriteGeneral(doc.general, viewMode)
+		}
+		if root.General.MultiColorWords != nil {
+			doc.setMultiColorWords(root.General.MultiColorWords)
 		}
 
 		w := ""
@@ -576,8 +535,6 @@ func (root *Root) Run() error {
 		log.Printf("open [%d]%s%s", n, doc.FileName, w)
 	}
 
-	root.setModeConfig()
-
 	root.ViewSync()
 	// Exit if fits on screen
 	if root.QuitSmall && root.docSmall() {
@@ -601,7 +558,7 @@ func (root *Root) Run() error {
 		defer func() {
 			root.Close()
 		}()
-		root.main(ctx, quitChan)
+		root.eventLoop(ctx, quitChan)
 	}()
 
 	for {
@@ -624,8 +581,6 @@ func (root *Root) optimizedMan() {
 	}
 
 	root.Doc.Caption = manPN
-	// Bug?? Clipboard fails when called by man.
-	root.Screen.DisableMouse()
 }
 
 func (root *Root) setModeConfig() {
@@ -652,7 +607,7 @@ func (root *Root) setMessage(msg string) {
 	root.Show()
 }
 
-func (root *Root) setMessagef(format string, a ...interface{}) {
+func (root *Root) setMessagef(format string, a ...any) {
 	msg := fmt.Sprintf(format, a...)
 	root.setMessage(msg)
 }
@@ -668,6 +623,7 @@ func (root *Root) debugMessage(msg string) {
 	log.Printf("%s:%s", root.Doc.FileName, msg)
 }
 
+// ToTcellStyle convert from ovStyle to tcell style.
 func ToTcellStyle(s OVStyle) tcell.Style {
 	style := tcell.StyleDefault
 	style = style.Background(tcell.GetColor(s.Background))
@@ -727,6 +683,7 @@ func overwriteGeneral(a general, b general) general {
 	}
 	a.AlternateRows = b.AlternateRows
 	a.ColumnMode = b.ColumnMode
+	a.ColumnRainbow = b.ColumnRainbow
 	a.LineNumMode = b.LineNumMode
 	a.WrapMode = b.WrapMode
 	a.FollowMode = b.FollowMode
@@ -747,6 +704,15 @@ func overwriteGeneral(a general, b general) general {
 	if b.SectionStartPosition != 0 {
 		a.SectionStartPosition = b.SectionStartPosition
 	}
+	if b.JumpTargetString != "" {
+		a.JumpTargetString = b.JumpTargetString
+	}
+	if b.JumpTarget != 0 {
+		a.JumpTarget = b.JumpTarget
+	}
+	if b.MultiColorWords != nil {
+		a.MultiColorWords = b.MultiColorWords
+	}
 	return a
 }
 
@@ -759,7 +725,7 @@ func (root *Root) prepareView() {
 	root.vWidth = max(root.vWidth, 1)
 	root.vHight = max(root.vHight, 1)
 
-	root.lnumber = make([]lineNumber, root.vHight+1)
+	root.lines = make([]line, root.vHight+1)
 	root.statusPos = root.vHight - statusLine
 }
 
@@ -812,9 +778,10 @@ func (root *Root) WriteLog() {
 	m.Export(os.Stdout, start, end)
 }
 
-func (root *Root) lineNumber(y int) lineNumber {
-	if y >= 0 && y <= len(root.lnumber) {
-		return root.lnumber[y]
+// lineInfo returns the line information from y on the screen.
+func (root *Root) lineInfo(y int) line {
+	if y >= 0 && y <= len(root.lines) {
+		return root.lines[y]
 	}
-	return root.lnumber[0]
+	return root.lines[0]
 }
