@@ -1,6 +1,8 @@
 package oviewer
 
-import "golang.org/x/exp/constraints"
+import (
+	"golang.org/x/exp/constraints"
+)
 
 // max returns the larger value of the argument.
 func max[T constraints.Ordered](a, b T) T {
@@ -37,3 +39,14 @@ func containsInt(list []int, e int) bool {
 	}
 	return false
 }
+
+// toLast toLast moves the specified string to the end.
+func toLast(list []string, s string) []string {
+	if len(s) == 0 {
+		return list
+	}
+
+	list = remove(list, s)
+	list = append(list, s)
+	return list
+}
